.. redirect-from:: /api/api_changes_old
.. redirect-from:: /users/whats_new_old
.. redirect-from:: /users/release_notes

.. _release-notes:

=============
Release notes
=============

.. include from another document so that it's easy to exclude this for releases
.. ifconfig:: releaselevel == 'dev'

   .. include:: release_notes_next.rst

Version 3.10
^^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.10.0.rst
    ../api/prev_api_changes/api_changes_3.10.9.rst
    ../api/prev_api_changes/api_changes_3.10.7.rst
    ../api/prev_api_changes/api_changes_3.10.1.rst
    ../api/prev_api_changes/api_changes_3.10.0.rst
    github_stats.rst
    prev_whats_new/github_stats_3.10.8.rst
    prev_whats_new/github_stats_3.10.7.rst
    prev_whats_new/github_stats_3.10.6.rst
    prev_whats_new/github_stats_3.10.5.rst
    prev_whats_new/github_stats_3.10.3.rst
    prev_whats_new/github_stats_3.10.1.rst
    prev_whats_new/github_stats_3.10.0.rst

Version 3.9
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.9.0.rst
    ../api/prev_api_changes/api_changes_3.9.2.rst
    ../api/prev_api_changes/api_changes_3.9.1.rst
    ../api/prev_api_changes/api_changes_3.9.0.rst
    prev_whats_new/github_stats_3.9.4.rst
    prev_whats_new/github_stats_3.9.3.rst
    prev_whats_new/github_stats_3.9.2.rst
    prev_whats_new/github_stats_3.9.1.rst
    prev_whats_new/github_stats_3.9.0.rst

Version 3.8
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.8.0.rst
    ../api/prev_api_changes/api_changes_3.8.1.rst
    ../api/prev_api_changes/api_changes_3.8.0.rst
    prev_whats_new/github_stats_3.8.3.rst
    prev_whats_new/github_stats_3.8.2.rst
    prev_whats_new/github_stats_3.8.1.rst
    prev_whats_new/github_stats_3.8.0.rst

Version 3.7
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.7.0.rst
    ../api/prev_api_changes/api_changes_3.7.0.rst
    prev_whats_new/github_stats_3.7.3.rst
    prev_whats_new/github_stats_3.7.2.rst
    prev_whats_new/github_stats_3.7.1.rst
    prev_whats_new/github_stats_3.7.0.rst

Version 3.6
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.6.0.rst
    ../api/prev_api_changes/api_changes_3.6.1.rst
    ../api/prev_api_changes/api_changes_3.6.0.rst
    prev_whats_new/github_stats_3.6.3.rst
    prev_whats_new/github_stats_3.6.2.rst
    prev_whats_new/github_stats_3.6.1.rst
    prev_whats_new/github_stats_3.6.0.rst

Version 3.5
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.5.2.rst
    prev_whats_new/whats_new_3.5.0.rst
    ../api/prev_api_changes/api_changes_3.5.3.rst
    ../api/prev_api_changes/api_changes_3.5.2.rst
    ../api/prev_api_changes/api_changes_3.5.0.rst
    prev_whats_new/github_stats_3.5.3.rst
    prev_whats_new/github_stats_3.5.2.rst
    prev_whats_new/github_stats_3.5.1.rst
    prev_whats_new/github_stats_3.5.0.rst

Version 3.4
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.4.0.rst
    ../api/prev_api_changes/api_changes_3.4.2.rst
    ../api/prev_api_changes/api_changes_3.4.0.rst
    prev_whats_new/github_stats_3.4.1.rst
    prev_whats_new/github_stats_3.4.0.rst

Version 3.3
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.3.0.rst
    ../api/prev_api_changes/api_changes_3.3.1.rst
    ../api/prev_api_changes/api_changes_3.3.0.rst
    prev_whats_new/github_stats_3.3.4.rst
    prev_whats_new/github_stats_3.3.3.rst
    prev_whats_new/github_stats_3.3.2.rst
    prev_whats_new/github_stats_3.3.1.rst
    prev_whats_new/github_stats_3.3.0.rst

Version 3.2
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.2.0.rst
    ../api/prev_api_changes/api_changes_3.2.0.rst
    prev_whats_new/github_stats_3.2.2.rst
    prev_whats_new/github_stats_3.2.1.rst
    prev_whats_new/github_stats_3.2.0.rst

Version 3.1
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.1.0.rst
    ../api/prev_api_changes/api_changes_3.1.1.rst
    ../api/prev_api_changes/api_changes_3.1.0.rst
    prev_whats_new/github_stats_3.1.3.rst
    prev_whats_new/github_stats_3.1.2.rst
    prev_whats_new/github_stats_3.1.1.rst
    prev_whats_new/github_stats_3.1.0.rst

Version 3.0
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_3.0.rst
    ../api/prev_api_changes/api_changes_3.0.1.rst
    ../api/prev_api_changes/api_changes_3.0.0.rst
    prev_whats_new/github_stats_3.0.3.rst
    prev_whats_new/github_stats_3.0.2.rst
    prev_whats_new/github_stats_3.0.1.rst
    prev_whats_new/github_stats_3.0.0.rst

Version 2.2
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_2.2.rst
    ../api/prev_api_changes/api_changes_2.2.0.rst

Version 2.1
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_2.1.0.rst
    ../api/prev_api_changes/api_changes_2.1.2.rst
    ../api/prev_api_changes/api_changes_2.1.1.rst
    ../api/prev_api_changes/api_changes_2.1.0.rst

Version 2.0
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_2.0.0.rst
    ../api/prev_api_changes/api_changes_2.0.1.rst
    ../api/prev_api_changes/api_changes_2.0.0.rst

Version 1.5
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_1.5.rst
    ../api/prev_api_changes/api_changes_1.5.3.rst
    ../api/prev_api_changes/api_changes_1.5.2.rst
    ../api/prev_api_changes/api_changes_1.5.0.rst

Version 1.4
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_1.4.rst
    ../api/prev_api_changes/api_changes_1.4.x.rst

Version 1.3
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_1.3.rst
    ../api/prev_api_changes/api_changes_1.3.x.rst

Version 1.2
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_1.2.2.rst
    prev_whats_new/whats_new_1.2.rst
    ../api/prev_api_changes/api_changes_1.2.x.rst

Version 1.1
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_1.1.rst
    ../api/prev_api_changes/api_changes_1.1.x.rst

Version 1.0
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/whats_new_1.0.rst

Version 0.x
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    prev_whats_new/changelog.rst
    prev_whats_new/whats_new_0.99.rst
    ../api/prev_api_changes/api_changes_0.99.x.rst
    ../api/prev_api_changes/api_changes_0.99.rst
    prev_whats_new/whats_new_0.98.4.rst
    ../api/prev_api_changes/api_changes_0.98.x.rst
    ../api/prev_api_changes/api_changes_0.98.1.rst
    ../api/prev_api_changes/api_changes_0.98.0.rst
    ../api/prev_api_changes/api_changes_0.91.2.rst
    ../api/prev_api_changes/api_changes_0.91.0.rst
    ../api/prev_api_changes/api_changes_0.90.1.rst
    ../api/prev_api_changes/api_changes_0.90.0.rst

    ../api/prev_api_changes/api_changes_0.87.7.rst
    ../api/prev_api_changes/api_changes_0.86.rst
    ../api/prev_api_changes/api_changes_0.85.rst
    ../api/prev_api_changes/api_changes_0.84.rst
    ../api/prev_api_changes/api_changes_0.83.rst
    ../api/prev_api_changes/api_changes_0.82.rst
    ../api/prev_api_changes/api_changes_0.81.rst
    ../api/prev_api_changes/api_changes_0.80.rst

    ../api/prev_api_changes/api_changes_0.73.rst
    ../api/prev_api_changes/api_changes_0.72.rst
    ../api/prev_api_changes/api_changes_0.71.rst
    ../api/prev_api_changes/api_changes_0.70.rst

    ../api/prev_api_changes/api_changes_0.65.1.rst
    ../api/prev_api_changes/api_changes_0.65.rst
    ../api/prev_api_changes/api_changes_0.63.rst
    ../api/prev_api_changes/api_changes_0.61.rst
    ../api/prev_api_changes/api_changes_0.60.rst

    ../api/prev_api_changes/api_changes_0.54.3.rst
    ../api/prev_api_changes/api_changes_0.54.rst
    ../api/prev_api_changes/api_changes_0.50.rst
    ../api/prev_api_changes/api_changes_0.42.rst
    ../api/prev_api_changes/api_changes_0.40.rst
